{% load aasrp %}

<link
    rel="stylesheet"
    href="{% aasrp_static 'aasrp/css/aa-srp-form.min.css' %}"
    integrity="sha512-zUBvh+eBMhqNzDZr9nxf4gFPKBpTNOoKPubyTi4jfXsYJyFBsDxc2TBVZViXCuOcMIW4Hnr61pADL8msH9EIKg=="
    crossorigin="anonymous"
>
